set more off
set matsize 10000

capture log close
log using tables6andA1, text replace

/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Replication of heterogeneous coefficient regressions underlying
	Tables 6 and A1 and of weighte-average results that are reported
	
	Output of betas and covariance matrices also used in Figures 14 and 15
		
	Program:
	
		1. Loads 4 digit prodcode data that have been
		2. Runs heterogeneous regressions with group-time effects, and 
		   additional checks with other FE
		3. Standard errors clustered at item level
		
		4. Load in weighted estimates and standard errors to created weighted
		   averages reported in tables
*/


/******************************************
	LOAD DATA AND PREPARE 	  
******************************************/

use 4julian_digit_Q300_P50_rho_nomerge_balticsincl_ner, clear

* Drop sectors that are not identified

drop if prodcode4==2101  | prodcode4==3043 | prodcode4==3045 | prodcode4==3204 |prodcode4==4861

* Drop if only one prodt or itm_id

egen cc1 = count(d_ln_phi), by(prodt)
drop if cc1<2
egen cc2 = count(d_ln_phi), by(itm_id)
drop if cc2<2
drop cc1 cc2

*  Generate quality regressors, linear, quadratic

ge d_ln_qual = ln_relUV_const*d_ln_C
ge d_ln_qual2 = ln_relUV_const*(d_ln_C)^2

* Generate H/F dummy interaction with group-time

egen prodtHF = group(prodt dom)

/******************************************
	OUTPUT PROGRAMS DEFINED	  
******************************************/

/*
	Estimation output program:
	
	1. Loads in `1', number of regressors
	2. Calculates total size of beta matrix less constant, `s'
	3. Creates a B matrix of coefficients, which is `s'/`1'*`1'
	4. Creates a V matrix ov COV, which is `s'*`s'
	5. Save matrices using name fed into `2', in output/beta_`2'.csv, and 
	   output/cov_`3'.csv
*/
	
capture program drop est_out
program define est_out
	mat b = e(b)
	mat v = e(V)
	
	local s = colsof(b)
	local var = `1'
	local incr = `s'/`1'

	mat B = J(`incr',1,.)
	local i = 1
	local j = `s'/`1'
	foreach X of numlist 1/`var'{
		mat B = [B,b[1,`i'..`j']']
		local i = `i'+`incr'
		local j = (`X'+1)*`incr'
	}
	mat B = B[1...,2...]
	mat V = v[1..`s',1..`s']
	
	svmat B
	svmat V
	outsheet B* if B1~=. using output/beta_`2'.csv, nonames c replace
	outsheet V* if V1~=. using output/cov_`2'.csv, nonames c replace
	
	drop B* V*
end

/*
	Estimation program for average beta based on any weights
*/

capture program drop mean_b
program define mean_b
	mat b = e(b)
	mat v = e(V)
	
	local s = colsof(b)
	local var = `1'
	local incr = `s'/`var'

	mat b = b[1,1..`s']
	mat v = v[1..`s',1..`s']
	
	mat w = J(`incr',1,1/`incr')
	
	mat mB = .
	mat seB = .
	mat tB = .
	local i = 1
	local j = `s'/`var'
	foreach X of numlist 1/`var'{
		mat b`X' = b[1,`i'..`j']
		mat v`X' = v[`i'..`j',`i'..`j']

		mat mb`X' = b`X'*w
		mat vb`X' = w'*v`X'*w
		mat se`X' = (vb`X'[1,1])^.5
		mat t`X' = mb`X'[1,1]/se`X'[1,1]
		
		mat mB = [mB,mb`X']
		mat seB = [seB,se`X']
		mat tB = [tB,t`X']

		local i = `i'+`incr'
		local j = (`X'+1)*`incr'		
	}
	mat mean_coef = [mB[1...,2...]\seB[1...,2...]\tB[1...,2...]]
end	

/******************************************
	HETEROGENEOUS SLOPES REGRESSIONS 	  
******************************************/

* Group time effects: Table 6 and Table A1

* Column (1)

reghdfe d_ln_phi i.prodcode#c.d_ln_pi_Pg, abs(prodt) cluster(id)
est_out 1 est_base1
mean_b 1
mat list mean_coef
svmat mean_coef
outsheet mean_coef* using output/hetero_base1.csv, nonames c replace
mat drop _all
drop mean_coef*
	
* Column (2)

reghdfe d_ln_phi i.prodcode#c.d_ln_pi_Pg i.prodcode#c.d_ln_qual, abs(prodt) cluster(id)	
est_out 2 est_base2
mean_b 2
mat list mean_coef
svmat mean_coef
outsheet mean_coef* using output/hetero_base2.csv, nonames c replace
mat drop _all
drop mean_coef*

* Non-linear effect of consumption: Table A1

* Column (3)

reghdfe d_ln_phi i.prodcode#c.d_ln_pi_Pg i.prodcode#c.d_ln_qual i.prodcode#c.d_ln_qual2, abs(prodt) cluster(id)
est_out 3 est_base3
mean_b 3
mat list mean_coef
svmat mean_coef
outsheet mean_coef* using output/hetero_base3.csv, nonames c replace
mat drop _all
drop mean_coef*

* Group time effects-HF: Table A1

* Column (4)

reghdfe d_ln_phi i.prodcode#c.d_ln_pi_Pg i.prodcode#c.d_ln_qual,  abs(prodtHF) cluster(id)
est_out 2 est_base4
mean_b 2
mat list mean_coef
svmat mean_coef
outsheet mean_coef* using output/hetero_base4.csv, nonames c replace
mat drop _all
drop mean_coef*

* Column (5)

reghdfe d_ln_phi i.prodcode#c.d_ln_pi_Pg i.prodcode#c.d_ln_qual, abs(prodt id)  cluster(id)
est_out 2 est_base5
mean_b 2
mat list mean_coef
svmat mean_coef
outsheet mean_coef* using output/hetero_base5.csv, nonames c replace
mat drop _all
drop mean_coef*

********************************************************
* 			WEIGHTED-AVERAGE COEFFICIENTS              *
********************************************************

/******************************************
	OUTPUT PROGRAMS DEFINED  
******************************************/
/*
	Estimation program for average beta based on any weights
	
	Program: loads in heterogeneous betas and spits out unweighted and 
	weighted mean beta, with standard error and t-stat. Does for 5 baseline 
	specifications
*/

capture program drop mean_b
program define mean_b
	
	* Load data to get shares of groups

	use output/groupchar_base2, clear
	mkmat sh_g, mat(share)
	
	keep if sh_gF~=1 & sh_gF~=0
	mkmat sh_g, mat(share_res)

	* Get betas and stack into a matrix
	
	clear 
	insheet using output/beta_est_base`1'.csv,c
	quietly des
	local  vars = r(k)
	 mkmat v*
	
	foreach X of numlist 1/`vars'{
		mat b`X' = v`X'
		mat drop v`X'
	}
	
	* Get variances
	
	clear
	insheet using output/cov_est_base`1'.csv,c
	quietly des
	local vars1 = r(k)
	local groups = `vars1'/`vars'
	mkmat v*

	foreach X of numlist 1/`vars1'{
		mat cov = (nullmat(cov),v`X')
		mat drop v`X'
	}

	* Weights

	mat w = share

	* Local to pull out correct covariance matrix
	
	mat w_mB = .
	mat w_seB = .
	mat w_tB = .
	
	local i = 1
	local j = `groups'
	foreach X of numlist 1/`vars'{
		mat cov`X' = cov[`i'..`j',`i'..`j']

		* Weighted mean

		mat w_mb`X' = w'*b`X'
		mat w_vb`X' = w'*cov`X'*w
		mat w_se`X' = (w_vb`X'[1,1])^.5
		mat w_t`X' = w_mb`X'[1,1]/w_se`X'[1,1]

		mat w_mB = [w_mB,w_mb`X']
		mat w_seB = [w_seB,w_se`X']
		mat w_tB = [w_tB,w_t`X']


		local i = `i'+`groups'
		local j = (`X'+1)*`groups'		
	}
	mat w_mean_coef = (nullmat(w_mean_coef),[w_mB[1...,2...]\w_seB[1...,2...]\w_tB[1...,2...]])
end	

* Run on beta files

 foreach X of numlist 1/5{
	mat drop _all
	mean_b `X'
	mat list w_mean_coef
	mat drop w_mean_coef
}

mat list w_mean_coef

log close
