set more off
set matsize 10000

capture log close
log using tableA2andA4, text replace

/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Replication of pooled coefficient regressions underlying
	Tables A2 and A4
	
	Program: 
	
		1. Loads 4 digit prodcode data 
		2. Runs pooled regressions with (1) group-time effects
		3. Standard errors clustered at item level
	
*/

/******************************************
	LOAD DATA AND PREPARE 	  
******************************************/

use 4julian_digit_Q300_P50_rho_nomerge_balticsincl_ner, clear

* Drop sectors that are not identified

drop if prodcode4==2101  | prodcode4==3043 | prodcode4==3045 | prodcode4==3204|prodcode4==4861

* Drop if only one prodt or itm_id

egen cc1 = count(d_ln_phi), by(prodt)
drop if cc1<2
egen cc2 = count(d_ln_phi), by(itm_id)
drop if cc2<2
drop cc1 cc2

*  Generate quality regressors, linear, quadratic

ge d_ln_qual = ln_relUV_const*d_ln_C
ge d_ln_qual2 = ln_relUV_const*(d_ln_C)^2

* Generate H/F dummy interaction with group-time

egen prodtHF = group(prodt dom)

/******************************************
	BASELINE: TABLE A2
******************************************/

* Column (1)

reghdfe d_ln_phi d_ln_pi_Pg, abs(prodt) cluster(id)
outreg2 using tables/regs_pooled_base.xls, excel 2aster dec(3) ctitle(CES) addstat("Group*time FE", e(K1)-e(M1)) replace

* Column (2)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual, abs(prodt) cluster(id)
outreg2 using tables/regs_pooled_base.xls, excel 2aster dec(3) ctitle(NH) addstat("Group*time FE", e(K1)-e(M1)) append

* Column (3)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual d_ln_qual2, abs(prodt) cluster(id)
outreg2 using tables/regs_pooled_base.xls, excel 2aster dec(3) ctitle(NH^2) addstat("Group*time FE", e(K1)-e(M1)) append

* Column (4)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual, abs(prodtHF) cluster(id)
outreg2 using tables/regs_pooled_base.xls, excel 2aster dec(3) ctitle(NH-HFprodtFE) addstat("Group*time FE", e(K1)-e(M1)) append

* Column (5)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual, abs(prodt id) cluster(id)
outreg2 using tables/regs_pooled_base.xls, excel 2aster dec(3) ctitle(itemFE) addstat("Group*time FE", e(K1)-e(M1), "Item FE", e(K2)-e(M2)) append


/******************************************
	ROBUSTNESS: TABLE A4
******************************************/

* Column (1)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual if dom==0, abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(F only) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)-e(M2)) replace

* Column (2)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual if dom==1, abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(H only) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)-e(M2)) append

* Column (3)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual if store_id==1, abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(Store 1) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)) append

* Column (4)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual if store_id==2, abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(Store 2) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)) append

* Column (5)

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual if store_id==3, abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(Store 3) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)) append

* Column (6)
	
sort prodcode4
merge prodcode4 using dta/foreignshare_pcode4
tab _merge
drop _merge

sort prodcode4
sum sh_gF if prodcode4~=prodcode4[_n-1], d
local q1=r(p25)
local q2=r(p50)
local q3=r(p75)

ge q1 = 0
ge q2 = 0
ge q3 = 0
ge q4 = 0
replace q1 = 1 if  sh_gF<=`q1'
replace q2 = 1 if  sh_gF>`q1'&sh_gF<=`q2'
replace q3 = 1 if  sh_gF>`q2'&sh_gF<=`q3'
replace q4 = 1 if  sh_gF>`q3'
ge dlnp1 =  d_ln_pi_Pg*q1
ge dlnp2 =  d_ln_pi_Pg*q2
ge dlnp3 =  d_ln_pi_Pg*q3
ge dlnp4 =  d_ln_pi_Pg*q4
ge dlnq1 =  d_ln_qual*q1
ge dlnq2 =  d_ln_qual*q2
ge dlnq3 =  d_ln_qual*q3
ge dlnq4 =  d_ln_qual*q4
drop q1-q4

reghdfe d_ln_phi dlnp1-dlnp4 dlnq1-dlnq4 , abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(F share) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)-e(M2)) append
drop dlnp* dlnq*

* Column (7)

egen _sdUV = sd(ln_relUV_const) if id~=id[_n-1], by(prodcode)
egen sd_lnrelUV_const = min(_sdUV ), by(prodcode)
drop _sdUV
sum sd_lnrelUV_const, d
local q1=r(p25)
local q2=r(p50)
local q3=r(p75)

ge q1 = 0
ge q2 = 0
ge q3 = 0
ge q4 = 0
replace q1 = 1 if  sd_lnrelUV_const<=`q1'
replace q2 = 1 if  sd_lnrelUV_const>`q1'&sd_lnrelUV_const<=`q2'
replace q3 = 1 if  sd_lnrelUV_const>`q2'&sd_lnrelUV_const<=`q3'
replace q4 = 1 if  sd_lnrelUV_const>`q3'
ge dlnp1 =  d_ln_pi_Pg*q1
ge dlnp2 =  d_ln_pi_Pg*q2
ge dlnp3 =  d_ln_pi_Pg*q3
ge dlnp4 =  d_ln_pi_Pg*q4
ge dlnq1 =  d_ln_qual*q1
ge dlnq2 =  d_ln_qual*q2
ge dlnq3 =  d_ln_qual*q3
ge dlnq4 =  d_ln_qual*q4
drop q1-q4

reghdfe d_ln_phi dlnp1-dlnp4 dlnq1-dlnq4 , abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(sd_UVqall) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)-e(M2)) append
drop dlnp* dlnq*

* Column (8)

sum ln_relUV_const if id~=id[_n-1],d
local q1=r(p25)
local q2=r(p50)
local q3=r(p75)
reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual if ln_relUV_const<=`q1', abs(prodt itm_id) cluster(id)

ge q1 = 0
ge q2 = 0
ge q3 = 0
ge q4 = 0
replace q1 = 1 if  ln_relUV_const<=`q1'
replace q2 = 1 if  ln_relUV_const>`q1'&ln_relUV_const<=`q2'
replace q3 = 1 if  ln_relUV_const>`q2'&ln_relUV_const<=`q3'
replace q4 = 1 if  ln_relUV_const>`q3'
ge dlnp1 =  d_ln_pi_Pg*q1
ge dlnp2 =  d_ln_pi_Pg*q2
ge dlnp3 =  d_ln_pi_Pg*q3
ge dlnp4 =  d_ln_pi_Pg*q4
ge dlnq1 =  d_ln_qual*q1
ge dlnq2 =  d_ln_qual*q2
ge dlnq3 =  d_ln_qual*q3
ge dlnq4 =  d_ln_qual*q4

reghdfe d_ln_phi dlnp1-dlnp4 dlnq1-dlnq4 , abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(lev_UVqall) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)-e(M2)) append
drop dlnp* dlnq*

* Column (9)

egen _m1 = mean(ln_relUV_const) if id~=id[_n-1] & dom==0, by(prodcode)
egen _m2 = mean(ln_relUV_const) if id~=id[_n-1] & dom==1, by(prodcode)
egen m1 = min(_m1), by(prodcode)
egen m2 = min(_m2), by(prodcode)
ge dmlnrelUV_HF = m1-m2
sum dmlnrel, d
local q1=r(p25)
local q2=r(p50)
local q3=r(p75)
	
ge q1 = 0
ge q2 = 0
ge q3 = 0
ge q4 = 0
replace q1 = 1 if  dmlnrelUV_HF<=`q1'
replace q2 = 1 if  dmlnrelUV_HF>`q1'&dmlnrelUV_HF<=`q2'
replace q3 = 1 if  dmlnrelUV_HF>`q2'&dmlnrelUV_HF<=`q3'
replace q4 = 1 if  dmlnrelUV_HF>`q3'
ge dlnp1 =  d_ln_pi_Pg*q1
ge dlnp2 =  d_ln_pi_Pg*q2
ge dlnp3 =  d_ln_pi_Pg*q3
ge dlnp4 =  d_ln_pi_Pg*q4
ge dlnq1 =  d_ln_qual*q1
ge dlnq2 =  d_ln_qual*q2
ge dlnq3 =  d_ln_qual*q3
ge dlnq4 =  d_ln_qual*q4

reghdfe d_ln_phi dlnp1-dlnp4 dlnq1-dlnq4 , abs(prodt itm_id) cluster(id)
outreg2 using tables/regs_pooled_robust.xls, excel 2aster dec(3) ctitle(dmlnrelUV_HF_qall) addstat("Group*time FE", e(K1)-e(M1),"Item FE", e(K2)-e(M2)) append
drop dlnp* dlnq*

log close
